@@ -41,25 +41,25 @@ _DjangoDb = Tuple[bool, bool, _DjangoDbDatabases, bool, _DjangoDbAvailableApps]
 
 
 __all__ = [
-    "django_db_setup",
+    "_live_server_helper",
+    "admin_client",
+    "admin_user",
+    "async_client",
+    "async_rf",
+    "client",
     "db",
-    "transactional_db",
+    "django_assert_max_num_queries",
+    "django_assert_num_queries",
+    "django_capture_on_commit_callbacks",
     "django_db_reset_sequences",
     "django_db_serialized_rollback",
-    "admin_user",
+    "django_db_setup",
     "django_user_model",
     "django_username_field",
-    "client",
-    "async_client",
-    "admin_client",
-    "rf",
-    "async_rf",
-    "settings",
     "live_server",
-    "_live_server_helper",
-    "django_assert_num_queries",
-    "django_assert_max_num_queries",
-    "django_capture_on_commit_callbacks",
+    "rf",
+    "settings",
+    "transactional_db",
 ]
 
 
@@ -165,8 +165,6 @@ def _django_db_helper(
     django_db_setup: None,
     django_db_blocker: DjangoDbBlocker,
 ) -> Generator[None, None, None]:
-    from django import VERSION
-
     if is_django_unittest(request):
         yield
         return
@@ -199,72 +197,64 @@ def _django_db_helper(
         "django_db_serialized_rollback" in request.fixturenames
     )
 
-    django_db_blocker.unblock()
+    with django_db_blocker.unblock():
+        import django.db
+        import django.test
 
-    import django.db
-    import django.test
+        if transactional:
+            test_case_class = django.test.TransactionTestCase
+        else:
+            test_case_class = django.test.TestCase
 
-    if transactional:
-        test_case_class = django.test.TransactionTestCase
-    else:
-        test_case_class = django.test.TestCase
+        _reset_sequences = reset_sequences
+        _serialized_rollback = serialized_rollback
+        _databases = databases
+        _available_apps = available_apps
 
-    _reset_sequences = reset_sequences
-    _serialized_rollback = serialized_rollback
-    _databases = databases
-    _available_apps = available_apps
+        class PytestDjangoTestCase(test_case_class):  # type: ignore[misc,valid-type]
+            reset_sequences = _reset_sequences
+            serialized_rollback = _serialized_rollback
+            if _databases is not None:
+                databases = _databases
+            if _available_apps is not None:
+                available_apps = _available_apps
 
-    class PytestDjangoTestCase(test_case_class):  # type: ignore[misc,valid-type]
-        reset_sequences = _reset_sequences
-        serialized_rollback = _serialized_rollback
-        if _databases is not None:
-            databases = _databases
-        if _available_apps is not None:
-            available_apps = _available_apps
+            # For non-transactional tests, skip executing `django.test.TestCase`'s
+            # `setUpClass`/`tearDownClass`, only execute the super class ones.
+            #
+            # `TestCase`'s class setup manages the `setUpTestData`/class-level
+            # transaction functionality. We don't use it; instead we (will) offer
+            # our own alternatives. So it only adds overhead, and does some things
+            # which conflict with our (planned) functionality, particularly, it
+            # closes all database connections in `tearDownClass` which inhibits
+            # wrapping tests in higher-scoped transactions.
+            #
+            # It's possible a new version of Django will add some unrelated
+            # functionality to these methods, in which case skipping them completely
+            # would not be desirable. Let's cross that bridge when we get there...
+            if not transactional:
 
-        # For non-transactional tests, skip executing `django.test.TestCase`'s
-        # `setUpClass`/`tearDownClass`, only execute the super class ones.
-        #
-        # `TestCase`'s class setup manages the `setUpTestData`/class-level
-        # transaction functionality. We don't use it; instead we (will) offer
-        # our own alternatives. So it only adds overhead, and does some things
-        # which conflict with our (planned) functionality, particularly, it
-        # closes all database connections in `tearDownClass` which inhibits
-        # wrapping tests in higher-scoped transactions.
-        #
-        # It's possible a new version of Django will add some unrelated
-        # functionality to these methods, in which case skipping them completely
-        # would not be desirable. Let's cross that bridge when we get there...
-        if not transactional:
+                @classmethod
+                def setUpClass(cls) -> None:
+                    super(django.test.TestCase, cls).setUpClass()
 
-            @classmethod
-            def setUpClass(cls) -> None:
-                super(django.test.TestCase, cls).setUpClass()
-                if VERSION < (4, 1):
-                    django.db.transaction.Atomic._ensure_durability = False
+                @classmethod
+                def tearDownClass(cls) -> None:
+                    super(django.test.TestCase, cls).tearDownClass()
 
-            @classmethod
-            def tearDownClass(cls) -> None:
-                if VERSION < (4, 1):
-                    django.db.transaction.Atomic._ensure_durability = True
-                super(django.test.TestCase, cls).tearDownClass()
+        PytestDjangoTestCase.setUpClass()
 
-    PytestDjangoTestCase.setUpClass()
+        test_case = PytestDjangoTestCase(methodName="__init__")
+        test_case._pre_setup()
 
-    test_case = PytestDjangoTestCase(methodName="__init__")
-    test_case._pre_setup()
+        yield
 
-    yield
+        test_case._post_teardown()
 
-    test_case._post_teardown()
+        PytestDjangoTestCase.tearDownClass()
 
-    PytestDjangoTestCase.tearDownClass()
-
-    if VERSION >= (4, 0):
         PytestDjangoTestCase.doClassCleanups()
 
-    django_db_blocker.restore()
-
 
 def validate_django_db(marker: pytest.Mark) -> _DjangoDb:
     """Validate the django_db marker.
@@ -616,6 +606,8 @@ class DjangoAssertNumQueries(Protocol):
         num: int,
         connection: Any | None = ...,
         info: str | None = ...,
+        *,
+        using: str | None = ...,
     ) -> django.test.utils.CaptureQueriesContext:
         pass  # pragma: no cover
 
@@ -627,13 +619,21 @@ def _assert_num_queries(
     exact: bool = True,
     connection: Any | None = None,
     info: str | None = None,
+    *,
+    using: str | None = None,
 ) -> Generator[django.test.utils.CaptureQueriesContext, None, None]:
+    from django.db import connection as default_conn, connections
     from django.test.utils import CaptureQueriesContext
 
-    if connection is None:
-        from django.db import connection as conn
-    else:
+    if connection and using:
+        raise ValueError('The "connection" and "using" parameter cannot be used together')
+
+    if connection is not None:
         conn = connection
+    elif using is not None:
+        conn = connections[using]
+    else:
+        conn = default_conn
 
     verbose = config.getoption("verbose") > 0
     with CaptureQueriesContext(conn) as context:
